@@ -1,15 +1,16 @@
 use std::{
     future::Future,
-    io::{self, Write},
+    io,
     pin::Pin,
     task::{Context, Poll},
 };
 
 use bytes::BytesMut;
-use flate2::{write::DeflateEncoder, Compression, Crc};
 use pin_project_lite::pin_project;
 use tokio::task::JoinHandle;
 
+use super::CompressionLevel;
+
 // (CDATA, CRC32, ISIZE)
 pub type GzData = (Vec<u8>, u32, u32);
 
@@ -21,9 +22,9 @@ pin_project! {
 }
 
 impl Deflate {
-    pub fn new(data: BytesMut, compression: Compression) -> Self {
+    pub fn new(data: BytesMut, compression_level: CompressionLevel) -> Self {
         Self {
-            handle: tokio::task::spawn_blocking(move || deflate(data, compression)),
+            handle: tokio::task::spawn_blocking(move || deflate(data, compression_level)),
         }
     }
 }
@@ -36,13 +37,7 @@ impl Future for Deflate {
     }
 }
 
-fn deflate(data: BytesMut, compression: Compression) -> io::Result<GzData> {
-    let mut encoder = DeflateEncoder::new(Vec::new(), compression);
-    encoder.write_all(&data[..])?;
-    let compressed_data = encoder.finish()?;
-
-    let mut crc = Crc::new();
-    crc.update(&data[..]);
-
-    Ok((compressed_data, crc.sum(), crc.amount()))
+fn deflate(data: BytesMut, compression_level: CompressionLevel) -> io::Result<GzData> {
+    use crate::writer::deflate_data;
+    deflate_data(&data, compression_level)
 }
